@@ -153,8 +153,8 @@ as.gWidgetsRGtk2.GtkTextView <- function(widget, ...) {
   ##               buffer$createTag(i,foreground = i)
   ##               buffer$createTag(Paste(i,".background"),background = i)
   ##             }
-  fontColors <-  colors()
-  lapply(colors(), function(i) {
+  fontColors <-  grDevices::colors()
+  lapply(fontColors(), function(i) {
     if(is.null(tagtbl$lookup(i))) 
       buffer$createTag(i,foreground = i)
     if(is.null(tagtbl$lookup(Paste(i,".background"))))
